CompoundStylerPartDescriptor class

Describes one nested styler section inside a compound styler.

Constructors

CompoundStylerPartDescriptor({required String fieldName, required String specName, required String stylerName, required List<String> ownerMixinNames, required List<StylerConstructorParamDescriptor> constructorParams, required List<String> constructorArguments})
const

Properties

constructorArguments List<String>
Named arguments passed to the nested styler constructor.
final
constructorParams List<StylerConstructorParamDescriptor>
Flattened constructor params accepted by the compound styler.
final
fieldName String
Field name on the compound spec.
final
hashCode int
The hash code for this object.
no setterinherited
ownerMixinNames List<String>
Owner mixins required by this nested surface.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
specName String
Nested spec name.
final
stylerName String
Nested styler name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited