KnownMixSymbolResolver class final

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportLibrary → LibraryElement
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requireInterface(String symbolName, Element errorElement) → InterfaceElement
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

load(BuildStep buildStep, Element errorElement) Future<KnownMixSymbolResolver>