StylerMixinBuilder class

Builds the _$XStylerMixin for a Styler class.

Constructors

StylerMixinBuilder({required String stylerName, required String specName, required List<StylerFieldModel> fields, required MixableStylerAnnotationConfig config, String? callMethodCode})
const

Properties

callMethodCode String?
final
config → MixableStylerAnnotationConfig
final
fields List<StylerFieldModel>
final
hashCode int
The hash code for this object.
no setterinherited
mixinName String
The mixin name.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
specName String
final
stylerName String
final

Methods

build() String
Builds the complete mixin code.
buildMembers({Set<String> methodOverrides = const {}}) String
Builds styler members without a surrounding mixin declaration.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited