ForwarderGroup class
A group of named factories derived from owner mixin methods.
- Inheritance
-
- Object
- StylerFactorySurfaceEntry
- ForwarderGroup
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
methodNames
→ List<
String> -
Mixin method names to promote, in generated factory order.
final
- mixinName → String
-
Owner mixin that declares the source methods.
final
-
requiredFieldNames
→ Set<
String> -
Fields that must be present before this group can be emitted.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isAvailableFor(
Set< String> fieldNames) → bool - Whether all required fields are available.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited