WidgetCallParam class
One parameter forwarded through generated widget/call APIs.
Constructors
Properties
- defaultValueCode → String?
-
Source code for a default value, if any (verbatim from the user's source).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPositional → bool
-
Whether this parameter is positional in the generated constructor.
Named parameters are emitted inside
{...}.final - isRequired → bool
-
Whether the parameter is required (positional-required or named-required).
final
- name → String
-
The parameter name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typeCode → String
-
Dart source code for the type, written to be visible from the annotated
library (already resolved by
library_scope.darthelpers).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited